@@ -2,8 +2,7 @@
 #  Fit the occupancy model of MacKenzie et al (2002).
 
 occu <- function(formula, data, knownOcc = numeric(0), starts,
-                 method = "BFGS", control = list(), se = TRUE,
-                 engine = c("C", "R")) {
+                 method = "BFGS", se = TRUE, engine = c("C", "R"), ...) {
     if(!is(data, "unmarkedFrameOccu"))
         stop("Data is not an unmarkedFrameOccu object.")
 
@@ -47,9 +46,6 @@ occu <- function(formula, data, knownOcc = numeric(0), starts,
     ## and fix bug causing crash when NAs are in V
 
     if(identical(engine, "C")) {
-#        V[is.na(V)] <- -999 # Armadillo's matrix-multiplication fails
-#                            # if values are missing. These will be
-#                            # ignored anyway
         nll <- function(params) {
             beta.psi <- params[1:nOP]
             beta.p <- params[(nOP+1):nP]
@@ -71,13 +67,12 @@ occu <- function(formula, data, knownOcc = numeric(0), starts,
         }
     }
 
-    if(missing(starts)) starts <- rep(0, nP)	#rnorm(nP)
-    fm <- optim(starts, nll, method = method, control = control,
-                hessian = se)
+    if(missing(starts)) starts <- rep(0, nP)
+    fm <- optim(starts, nll, method = method, hessian = se, ...)
     opt <- fm
     if(se) {
         tryCatch(covMat <- solve(fm$hessian),
-                 error=function(x) stop(simpleError("Hessian is singular.  Try using fewer covariates.")))
+                 error=function(x) stop(simpleError("Hessian is singular.  Try providing starting values or using fewer covariates.")))
     } else {
         covMat <- matrix(NA, nP, nP)
     }
